#
# spec file for package python-openqa_client
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-openqa_client
Version:        4.2.3
Release:        1.2
Summary:        Python openQA client library
License:        GPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/os-autoinst/openQA-python-client
Source:         https://github.com/os-autoinst/openQA-python-client/archive/refs/tags/%{version}.tar.gz#/python-openqa_client-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-requests
Requires:       python-typing_extensions
BuildArch:      noarch
%python_subpackages

%description
This is a client for the openQA API, based on requests.

%prep
%setup -q -n openQA-python-client-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license COPYING
%{python_sitelib}/*
%pycache_only %{python_sitelib}/*/__pycache__/*

%changelog
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 4.2.3:
  * Add py.typed marker to the package
  * Include the response text in RequestError (kalikiana)
  * Support `REQUESTS_CA_BUNDLE` and `CURL_CA_BUNDLE`
    environment variables (ricardobranco777)
* Thu Dec  1 2022 Ondřej Súkup <mimi.vx@gmail.com>
- update to 4.2.2
- drop _service
- add python-typing_extensions as dependency for compatibility
  with older versions of python
  * Make Exceptions proper objects with members
  * Only retry requests on certain status codes
  * Add class global retries and wait values to allow configuration
  * Add type hints
  * Stop encoding X-API-Microtime as bytes
  * Improve handling of quirky API behaviour regarding settings parameters
* Fri Sep  4 2020 mimi.vx@gmail.com
- Update to version 4.1.1:
- enable tests
  * Fix use of 'latest' param when querying jobs
  * Drop a rogue word from `do_request` docstring, rewrap
  * Tweak release script to use 'pypi' repo
  * Handle YAML responses as well as JSON (#12)
  * Add a 'parse' argument for `do_request` to skip parsing
  * Add toml to CI requires (for coverage to read TOML config)
  * tox: run `coverage xml` explicitly
  * Improve the ugly sed hack fix for the coverage vs. tox venv issue
  * Update release.sh to use pep517
  * Add pyproject.toml to comply with PEP-517 / PEP-518
  * black-ify code and add black to CI config
  * Move source under src/ , fix tox config to run tests on package
  * Use f-strings for string formatting
  * Drop Python 2 support, and some Python 2-specific workarounds
  * Have MANIFEST.in exclude itself
  * Add a MANIFEST.in to exclude some stuff we don't want
  * Fix tests to run on ancient pytest (I hope)
  * Fix more brokenness in setup.py
  * Fix release.sh for no spaces in setup.py setup()
  * Drop duplicated description line in setup.py
  * Update release.sh to use Python 3
  * Drop WaitError exception
  * find_clones: don't edit list while iterating it
  * _add_auth_headers: don't modify the original request
  * setup.py: don't import os, we don't use it
  * setup.py: Remove runtime dependency on setuptools (@jayvdb) (#9)
  * setup.py: more cleanups based on sample project
  * setup.py: we don't use find_packages, don't import it
  * setup.py: no spaces for arg assignments
  * setup.py: handle long_description as per pypa sample project
  * Update release script to publish to PyPI
  * Fix long description for pypi
  * **API**: update constants to match upstream 4d89041
  * Remove waiting state
  * Add incomplete result "timeout_exceeded"
  * Update job state constants for recent upstream changes
* Sat Jul  8 2017 mimi.vx@gmail.com
- Update to version 1.3.0:
  * Drop functions I deprecated months ago
  * update constants from upstream
  * use tuples not lists for constants
  * fix a one item tuple
  * update gitignore
  * drop unnecessary comment
  * Add version to __init__.py and add a release script
  * Update README to mention const module
  * Add a CHANGELOG to prepare for a proper release
- move to singlespec
* Mon Jun 29 2015 lnussel@suse.de
- initial package
